@@ -24,7 +24,7 @@ import contextlib
 
 from dataiter import util
 
-__version__ = "0.36"
+__version__ = "0.37"
 
 DEFAULT_PEEK_ELEMENTS = 10
 DEFAULT_PEEK_ITEMS = 3
@@ -43,7 +43,7 @@ try:
 except LookupError:
     with contextlib.suppress(Exception):
         # Use Numba automatically if found
-        # and a calling a trivial function works.
+        # and calling a trivial function works.
         import numba
         try:
             @numba.njit(cache=True)
@@ -77,7 +77,6 @@ from dataiter.aggregate import mean # noqa
 from dataiter.aggregate import median # noqa
 from dataiter.aggregate import min # noqa
 from dataiter.aggregate import mode # noqa
-from dataiter.aggregate import nrow # noqa
 from dataiter.aggregate import nth # noqa
 from dataiter.aggregate import quantile # noqa
 from dataiter.aggregate import std # noqa
