@@ -429,28 +429,10 @@ def mode1(x):
     try:
         return statistics.mode(x)
     except statistics.StatisticsError:
-        # Python < 3.8 with several elements tied for mode,
-        # will return one of the tied elements at random.
+        # Python < 3.8 with several elements tied for mode.
+        # Return the first encountered of the tied elements.
         return Counter(x).most_common(1)[0][0]
 
-def nrow(data):
-    """
-    Return the amount of rows in `data`.
-
-    This is a useful shorthand for `data.nrow` in contexts where you don't have
-    direct access to the data frame in question, e.g. in group-by-aggregate
-
-    .. warning:: Deprecated, please use :func:`count` instead.
-
-    >>> data = di.read_csv("data/listings.csv")
-    >>> data.group_by("hood").aggregate(n=di.nrow)
-    """
-    if not getattr(nrow, "warning_shown", False):
-        print('Warning: nrow is deprecated, please use count instead')
-        print('e.g. data.group_by("hood").aggregate(n=di.count())')
-        nrow.warning_shown = True
-    return data.nrow
-
 @composite
 def nth(x, index, *, drop_na=False):
     """
@@ -614,12 +596,13 @@ def sum(x, *, drop_na=True):
 
 def use_numba(x):
     # Numba can't handle all dtypes, use conditionally.
+    # Strings are supported, but performance is bad.
+    # https://numba.pydata.org/numba-doc/dev/reference/pysupported.html#str
     return dataiter.USE_NUMBA and (
         np.issubdtype(x.dtype, np.bool_) or
         np.issubdtype(x.dtype, np.datetime64) or
         np.issubdtype(x.dtype, np.floating) or
-        np.issubdtype(x.dtype, np.integer) or
-        np.issubdtype(x.dtype, np.unicode_))
+        np.issubdtype(x.dtype, np.integer))
 
 @composite
 def var(x, *, ddof=0, drop_na=True):
