@@ -65,7 +65,7 @@ class ListOfDicts(list):
     https://github.com/otsaloma/attd
     """
 
-    def __init__(self, dicts=(), as_is=False):
+    def __init__(self, dicts=(), *, as_is=False):
         """
         Return a new list of dicts.
 
@@ -177,7 +177,7 @@ class ListOfDicts(list):
         >>> reviews = di.read_json("data/listings-reviews.json")
         >>> listings.anti_join(reviews, "id")
         """
-        by1, by2 = self._split_by(*by)
+        by1, by2 = self._split_join_by(*by)
         extract1 = operator.itemgetter(*by1)
         extract2 = operator.itemgetter(*by2)
         other_ids = set(map(extract2, other))
@@ -234,15 +234,15 @@ class ListOfDicts(list):
 
     @deco.obsoletes
     @deco.new_from_generator
-    def fill_missing(self, **key_value_pairs):
+    def fill_missing_keys(self, **key_value_pairs):
         """
         Return list with missing keys added.
 
         If `key_value_pairs` not given, fill all missing keys with ``None``.
 
         >>> data = di.read_json("data/listings.json")
-        >>> data = data.fill_missing(price=None)
-        >>> data = data.fill_missing()
+        >>> data = data.fill_missing_keys(price=None)
+        >>> data = data.fill_missing_keys()
         """
         if not key_value_pairs:
             keys = util.unique_keys(itertools.chain(*self))
@@ -307,7 +307,7 @@ class ListOfDicts(list):
                     yield item
 
     @classmethod
-    def from_json(cls, string, keys=[], types={}, **kwargs):
+    def from_json(cls, string, *, keys=[], types={}, **kwargs):
         """
         Return a new list of dicts from JSON `string`.
 
@@ -349,7 +349,7 @@ class ListOfDicts(list):
         b = other.deepcopy().modify(_bid_=lambda x: next(bcounter))
         ab = a.deepcopy().left_join(b, *by)
         # Fill in missing _bid_ with bogus values.
-        ab = ab.fill_missing(_bid_=next(bcounter))
+        ab = ab.fill_missing_keys(_bid_=next(bcounter))
         # Check which items of b were not joined into a,
         # if no items remain, full join is the same as left join ab.
         b = b.anti_join(ab, "_bid_")
@@ -357,7 +357,7 @@ class ListOfDicts(list):
             return ab.unselect("_aid_", "_bid_")
         ba = b.left_join(a, *by)
         # Fill in missing _aid_ with bogus values.
-        ba = ba.fill_missing(_aid_=next(acounter))
+        ba = ba.fill_missing_keys(_aid_=next(acounter))
         return (ab + ba).sort(_aid_=1, _bid_=1).unselect("_aid_", "_bid_")
 
     def group_by(self, *keys):
@@ -395,7 +395,7 @@ class ListOfDicts(list):
         >>> reviews = di.read_json("data/listings-reviews.json")
         >>> listings.inner_join(reviews, "id")
         """
-        by1, by2 = self._split_by(*by)
+        by1, by2 = self._split_join_by(*by)
         extract1 = operator.itemgetter(*by1)
         extract2 = operator.itemgetter(*by2)
         other_by_id = {extract2(x): x for x in reversed(other)}
@@ -440,7 +440,7 @@ class ListOfDicts(list):
         >>> reviews = di.read_json("data/listings-reviews.json")
         >>> listings.left_join(reviews, "id")
         """
-        by1, by2 = self._split_by(*by)
+        by1, by2 = self._split_join_by(*by)
         extract1 = operator.itemgetter(*by1)
         extract2 = operator.itemgetter(*by2)
         other_by_id = {extract2(x): x for x in reversed(other)}
@@ -527,7 +527,7 @@ class ListOfDicts(list):
         """
         return [x.get(key, default) for x in self]
 
-    def print_(self, max_items=None):
+    def print_(self, *, max_items=None):
         """
         Print list to ``sys.stdout``.
 
@@ -537,9 +537,9 @@ class ListOfDicts(list):
 
         >>> di.read_json("data/listings.json").print_()
         """
-        print(self.to_string(max_items))
+        print(self.to_string(max_items=max_items))
 
-    def print_missing_counts(self):
+    def print_na_counts(self):
         """
         Print counts of missing values by key.
 
@@ -547,7 +547,7 @@ class ListOfDicts(list):
         considered missing.
 
         >>> data = di.read_json("data/listings.json")
-        >>> data.print_missing_counts()
+        >>> data.print_na_counts()
         """
         print("Missing counts:")
         for key in util.unique_keys(itertools.chain(*self)):
@@ -557,7 +557,7 @@ class ListOfDicts(list):
             print(f"... {key}: {n} ({pc:.1f}%)")
 
     @classmethod
-    def read_csv(cls, path, encoding="utf-8", sep=",", header=True, keys=[], types={}):
+    def read_csv(cls, path, *, encoding="utf-8", sep=",", header=True, keys=[], types={}):
         """
         Return a new list from CSV file `path`.
 
@@ -585,7 +585,7 @@ class ListOfDicts(list):
             return data
 
     @classmethod
-    def read_json(cls, path, encoding="utf-8", keys=[], types={}, **kwargs):
+    def read_json(cls, path, *, encoding="utf-8", keys=[], types={}, **kwargs):
         """
         Return a new list from JSON file `path`.
 
@@ -595,7 +595,7 @@ class ListOfDicts(list):
         dict mapping keys to datatypes. `kwargs` are passed to ``json.load``.
         """
         with util.xopen(path, "rt", encoding=encoding) as f:
-            return cls.from_json(f.read(), keys, types, **kwargs)
+            return cls.from_json(f.read(), keys=keys, types=types, **kwargs)
 
     @classmethod
     def read_pickle(cls, path):
@@ -667,7 +667,7 @@ class ListOfDicts(list):
         >>> reviews = di.read_json("data/listings-reviews.json")
         >>> listings.semi_join(reviews, "id")
         """
-        by1, by2 = self._split_by(*by)
+        by1, by2 = self._split_join_by(*by)
         extract1 = operator.itemgetter(*by1)
         extract2 = operator.itemgetter(*by2)
         other_ids = set(map(extract2, other))
@@ -697,7 +697,21 @@ class ListOfDicts(list):
             data = sorted(data, key=sort_key, reverse=dir < 0)
         return self._new(data)
 
-    def _split_by(self, *by):
+    def split(self, *by):
+        """
+        Split list into groups and return a list of their indices.
+
+        >>> data = di.ListOfDicts({"x": x} for x in [1, 2, 2, 3, 3, 3])
+        >>> data.split("x")
+        """
+        extract = operator.itemgetter(*by)
+        indices_by_group = {}
+        for i, item in enumerate(self):
+            id = extract(item)
+            indices_by_group.setdefault(id, []).append(i)
+        return list(indices_by_group.values())
+
+    def _split_join_by(self, *by):
         by1 = [x if isinstance(x, str) else x[0] for x in by]
         by2 = [x if isinstance(x, str) else x[1] for x in by]
         return by1, by2
@@ -751,7 +765,7 @@ class ListOfDicts(list):
         import pandas as pd
         return pd.DataFrame(self._to_columns())
 
-    def to_string(self, max_items=None):
+    def to_string(self, *, max_items=None):
         """
         Return list as a string formatted for display.
 
@@ -802,7 +816,7 @@ class ListOfDicts(list):
                     del item[key]
             yield item
 
-    def write_csv(self, path, encoding="utf-8", header=True, sep=","):
+    def write_csv(self, path, *, encoding="utf-8", header=True, sep=","):
         """
         Write list to CSV file `path`.
 
@@ -826,7 +840,7 @@ class ListOfDicts(list):
                 item = {**dict.fromkeys(keys), **item}
                 writer.writerow(item)
 
-    def write_json(self, path, encoding="utf-8", **kwargs):
+    def write_json(self, path, *, encoding="utf-8", **kwargs):
         """
         Write list to JSON file `path`.
 
